diff --git a/hog/operator_generation/function_space_implementations/__init__.py b/hog/operator_generation/function_space_implementations/__init__.py
index 83f757d5d24ff92f53857294feaba132c63d2ecd..b133d9c3e2a9fb91d0a0adb2c637c1069dc457c8 100644
--- a/hog/operator_generation/function_space_implementations/__init__.py
+++ b/hog/operator_generation/function_space_implementations/__init__.py
@@ -16,9 +16,9 @@
 
 __all__ = [
     "function_space_impl_base",
-    "function_space_impl_factor",
-    "p0_function_space_impl",
-    "p1_function_space_impl",
-    "p2_function_space_impl",
-    "n1e1_function_space_impl",
+    "function_space_impl_factory",
+    "p0_space_impl",
+    "p1_space_impl",
+    "p2_space_impl",
+    "n1e1_space_impl",
 ]
diff --git a/hog/operator_generation/function_space_implementations/function_space_impl_base.py b/hog/operator_generation/function_space_implementations/function_space_impl_base.py
index a618d138db3c57c189c733a5858b675ab0e91930..d410fbc9de96af4b96d3e33ee855d78e8299068a 100644
--- a/hog/operator_generation/function_space_implementations/function_space_impl_base.py
+++ b/hog/operator_generation/function_space_implementations/function_space_impl_base.py
@@ -55,8 +55,8 @@ class FunctionSpaceImpl(ABC):
     implementation agnostic way.
 
     It is impossible to create an instance of this abstract base class directly.
     Preferrably, use the static method `create_impl` which selects the correct
     derived class for the `FunctionSpace`.
     """
 
     def __init__(
@@ -70,8 +70,8 @@ class FunctionSpaceImpl(ABC):
 
         It is impossible to create an instance of this abstract base class
         directly. This __init__ method is to be called by the derived classes.
-        Preferrably, use the static method `create_impl` which selects the
-        correct derived class for the `FunctionSpace`.
+        Preferrably, use `function_space_impl_factory.create_impl` which
+        selects the correct derived class for the `FunctionSpace`.
         """
         self.fe_space = fe_space
         self.name = name
@@ -55,8 +55,8 @@ class FunctionSpaceImpl(ABC):
 
     It is impossible to create an instance of this abstract base class directly.
-    Preferrably, use the static method `create_impl` which selects the correct
-    derived class for the `FunctionSpace`.
+    Preferrably, use `function_space_impl_factory.create_impl` which selects
+    the correct derived class for the `FunctionSpace`.
     """
 